==> nextcloud-14.0.13.zip: nextcloud/apps/files/l10n/el.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Μη διαθέσιμος χώρος αποθήκευσης προσωρινά",
    "Storage invalid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Unknown error" : "Άγνωστο σφάλμα",
    "All files" : "Όλα τα αρχεία",
    "Recent" : "Τελευταία",
    "Favorites" : "Αγαπημένα",
    "File could not be found" : "Δεν μπορεί να βρεθεί το αρχείο",
    "Move or copy" : "Μετακίνηση ή αντιγραφή",
    "Download" : "Λήψη",
    "Delete" : "Διαγραφή",
    "Home" : "Σπίτι",
    "Close" : "Κλείσιμο",
    "Could not create folder \"{dir}\"" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\"",
    "This will stop your current uploads." : "Αυτό θα σταματήσει τις τρέχουσες μεταφορτώσεις.",
    "Upload cancelled." : "Η αποστολή ακυρώθηκε.",
    "Processing files …" : "Γίνεται επεξεργασία των αρχείων ...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Αδυναμία φόρτωσης {filename} καθώς είναι κατάλογος αρχείων ή έχει 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Δεν υπάρχει αρκετός ελεύθερος χώρος, μεταφορτώνετε μέγεθος {size1} αλλά υπάρχει χώρος μόνο {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Φάκελος προορισμού \"{dir}\" δεν υπάρχει πια",
    "Not enough free space" : "Δεν υπάρχει αρκετός ελεύθερος χώρος.",
    "An unknown error has occurred" : "Ένα άγνωστο σφάλμα προέκυψε",
    "Uploading …" : "Γίνεται μεταφόρτωση ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} από {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Η μεταφόρτωση αυτού του αντικειμένου δεν υποστηρίζεται",
    "Target folder does not exist any more" : "Ο επιλεγμένος φάκελος δεν υπάρχει πλέον",
    "Actions" : "Ενέργειες",
    "Rename" : "Μετονομασία",
    "Copy" : "Αντιγραφή",
    "Disconnect storage" : "Αποσυνδεδεμένος αποθηκευτικός χώρος",
    "Unshare" : "Διακοπή διαμοιρασμού",
    "Could not load info for file \"{file}\"" : "Δεν μπορέσαμε να φορτώσουμε πληροφορίες για το αρχείο \"{file}\"",
    "Files" : "Αρχεία",
    "Details" : "Λεπτομέρειες",
    "Select" : "Επιλογή",
    "Pending" : "Εκκρεμεί",
    "Unable to determine date" : "Αδυναμία προσδιορισμού ημερομηνίας ",
    "This operation is forbidden" : "Αυτή η ενέργεια δεν επιτρέπεται",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλώ ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
    "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
    "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Αδυναμία αντιγραφής του \"{file}\". Υπάρχει ήδη.",
    "Could not copy \"{file}\"" : "Αδυναμία αντιγραφής του \"{file}\"",
    "Copied {origin} inside {destination}" : "Αντιγράφτηκε το {origin} στο {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Αντιγράφτηκε το {origin} και {nbfiles} άλλα αρχεία στο {destination}",
    "{newName} already exists" : "Το {newname} υπάρχει ήδη",
    "Could not rename \"{fileName}\", it does not exist any more" : "Δεν μπορέσαμε να μετονομάσουμε \"{fileName}\", το αρχείο δεν υπάρχει πια.",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{targetName}\" χρησιμοποιείται ήδη στον φάκελο\"{dir}\". Παρακαλούμε διαλέξτε ένα διαφορετικό όνομα.",
    "Could not rename \"{fileName}\"" : "Αδυναμία μετονομασίας του \"{fileName}\"",
    "Could not create file \"{file}\"" : "Αδυναμία δημιουργίας του \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Δεν μπορέσαμε να δημιουργήσουμε το αρχείο \"{file}\" επειδή υπάρχει ήδη",
    "Could not create folder \"{dir}\" because it already exists" : "Δεν μπορέσαμε να δημιουργήσουμε τον φάκελο \"{dir}\" επειδή υπάρχει ήδη",
    "Error deleting file \"{fileName}\"." : "Αδυναμία διαγραφής του \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Κανένα αποτέλεσμα αναζήτησης σε άλλους φακέλους για {tag}{filter}{endtag}",
    "Name" : "Όνομα",
    "Size" : "Μέγεθος",
    "Modified" : "Τροποποιήθηκε",
    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
    "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
    "{dirs} and {files}" : "{dirs} και {files}",
    "_including %n hidden_::_including %n hidden_" : ["περιλαμβάνεται %n κρυμμένο ","περιλαμβάνονται %n κρυμμένα "],
    "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα φόρτωσης ή δημιουργίας αρχείων εδώ",
    "_Uploading %n file_::_Uploading %n files_" : ["Ανέβασμα %n αρχείου","Ανέβασμα %n αρχείων"],
    "New" : "Νέο",
    "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
    "File name cannot be empty." : "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
    "\"/\" is not allowed inside a file name." : "Το \"/\" δεν είναι επιτρεπτό εντός του ονόματος αρχείου.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" δεν είναι ένας επιτρεπτός τύπος αρχείου",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός χώρος του {owner} είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Ο αποθηκευτικός χώρος του {owner} είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ο αποθηκευτικός χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ταιριάζουν '{filter}' ","ταιριάζουν '{filter}'"],
    "View in folder" : "Προβολή στον φάκελο",
    "Copied!" : "Αντιγράφηκε!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση στο αρχείο/φάκελο)",
    "Path" : "Διαδρομή",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Προτιμώμενα",
    "Favorite" : "Αγαπημένο",
    "New folder" : "Νέος φάκελος",
    "Upload file" : "Αποστολή αρχείου",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα",
    "An error occurred while trying to update the tags" : "Ένα σφάλμα προέκυψε κατά τη διάρκεια ενημέρωσης των ετικετών",
    "Added to favorites" : "Προσθήκη στα αγαπημένα",
    "Removed from favorites" : "Αφαίρεση από τα αγαπημένα",
    "You added {file} to your favorites" : "Προσθέσατε {file} στα αγαπημένα σας",
    "You removed {file} from your favorites" : "Αφαιρέσατε {file} από τα αγαπημένα σας",
    "File changes" : "Αλλαγές αρχείου",
    "Created by {user}" : "Δημιουργήθηκε από τον/την {user}",
    "Changed by {user}" : "Άλλαξε από {user}",
    "Deleted by {user}" : "Διαγράφτηκε από {user}",
    "Restored by {user}" : "Επαναφέρθηκε από {user}",
    "Renamed by {user}" : "Μετονομάστηκε από {user}",
    "Moved by {user}" : "Μετακινήθηκε από {user}",
    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
    "You created {file}" : "Δημιουργήσατε {file}",
    "You created an encrypted file in {file}" : "Δημιουργήσατε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{user} created {file}" : "{user} δημιούργησε {file}",
    "{user} created an encrypted file in {file}" : "{user} δημιούργησε ένα κρυπτογραφημένο αρχείο στο {file}",
    "{file} was created in a public folder" : "{file} δημιουργήθηκε σε δημόσιο φάκελο",
    "You changed {file}" : "Αλλάξατε {file}",
    "{user} changed {file}" : "{user} άλλαξε {file}",
    "You deleted {file}" : "Διαγράψτε το {file}",
    "{user} deleted {file}" : "ο {user} διέγραψε το {file}",
    "You restored {file}" : "Επαναφέρατε {file}",
    "{user} restored {file}" : "{user} επανέφερε {file}",
    "You renamed {oldfile} to {newfile}" : "Μετονομάσατε {oldfile} σε {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} μετονόμασε {oldfile} σε {newfile}",
    "You moved {oldfile} to {newfile}" : "Μεταφέρατε {oldfile} σε {newfile}",
    "{user} moved {oldfile} to {newfile}" : "Μετέφερε {oldfile} σε {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Ένα αρχείο έχει προστεθεί ή αφαιρεθεί από τα <strong>αγαπημένα</strong> σας",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Ένα αρχείο ή φάκελος έχει <strong>αλλάξει</strong> ή <strong>μετονομάστηκε</strong>",
    "A new file or folder has been <strong>created</strong>" : "Ένα νέο αρχείο ή κατάλογος έχουν <strong>δημιουργηθεί</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>διαγραφεί</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Βάλτε όριο στις ειδοποιήσεις για τη δημιουργία και αλλαγές στα <strong>αγαπημένα σας αρχεία</strong> <em>(Μόνο Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "Έγινε <strong>επαναφορά</strong> ενός αρχείου ή φακέλου",
    "Unlimited" : "Απεριόριστο",
    "Upload (max. %s)" : "Διαμοιρασμός (max. %s)",
    "File Management" : "Διαχείριση αρχείων",
    "%s used" : "%sσε χρήση",
    "%1$s of %2$s used" : "χρησιμοποιούνται %1$s από %2$s",
    "Settings" : "Ρυθμίσεις",
    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Χρησιμοποιήστε αυτή την διεύθυνση, προκειμένου να <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">έχετε πρόσβαση στα αρχεία σας μέσω WebDAV</a>",
    "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
    "No files in here" : "Δεν υπάρχουν αρχεία",
    "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Select all" : "Επιλογή όλων",
    "Upload too large" : "Πολύ μεγάλο αρχείο προς αποστολή",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να ανεβάσετε υπερβαίνουν το μέγιστο μέγεθος αποστολής αρχείων σε αυτόν τον διακομιστή.",
    "No favorites yet" : "Κανένα αγαπημένο ακόμα",
    "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα  θα εμφανιστούν εδώ ",
    "Tags" : "Ετικέτες",
    "Deleted files" : "Διεγραμμένα αρχεία",
    "Shares" : "Κοινόχρηστα",
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "Deleted shares" : "Διαγραμμένα κοινόχρηστα",
    "Text file" : "Αρχείο κειμένου",
    "New text file.txt" : "Νέο αρχείο κειμένου.txt",
    "Target folder" : "Φάκελος προορισμού",
    "File handling" : "Διαχείριση αρχείων",
    "Maximum upload size" : "Μέγιστο μέγεθος αποστολής",
    "max. possible: " : "μέγιστο δυνατό:",
    "Save" : "Αποθήκευση",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Με PHP-FPM μπορεί να χρειαστούν μέχρι και 5 λεπτά για να ενεργοποιηθούν οι αλλαγές.",
    "Missing permissions to edit from here." : "Δεν υπάρχουν τα απαραίτητα δικαιώματα για να γίνει τροποποιήση σε αυτό το σημείο.",
    "%s of %s used" : "%s από %s σε χρήση",
    "Cancel upload" : "Ακύρωση μεταφόρτωσης",
    "%1$s%% of %2$s used" : "%1$s%% από %2$s σε χρήση"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.3.zip: nextcloud/apps/files/l10n/el.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Μη διαθέσιμος χώρος αποθήκευσης προσωρινά",
    "Storage invalid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Unknown error" : "Άγνωστο σφάλμα",
    "All files" : "Όλα τα αρχεία",
    "Recent" : "Τελευταία",
    "Favorites" : "Αγαπημένα",
    "File could not be found" : "Δεν μπορεί να βρεθεί το αρχείο",
    "Move or copy" : "Μετακίνηση ή αντιγραφή",
    "Download" : "Λήψη",
    "Delete" : "Διαγραφή",
    "Home" : "Σπίτι",
    "Close" : "Κλείσιμο",
    "Could not create folder \"{dir}\"" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\"",
    "This will stop your current uploads." : "Αυτό θα σταματήσει τις τρέχουσες μεταφορτώσεις.",
    "Upload cancelled." : "Η αποστολή ακυρώθηκε.",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Αδυναμία φόρτωσης {filename} καθώς είναι κατάλογος αρχείων ή έχει 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Δεν υπάρχει αρκετός ελεύθερος χώρος, μεταφορτώνετε μέγεθος {size1} αλλά υπάρχει χώρος μόνο {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Φάκελος προορισμού \"{dir}\" δεν υπάρχει πια",
    "Not enough free space" : "Δεν υπάρχει αρκετός ελεύθερος χώρος.",
    "Uploading …" : "Γίνεται μεταφόρτωση ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} από {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Ο επιλεγμένος φάκελος δεν υπάρχει πλέον",
    "Actions" : "Ενέργειες",
    "Rename" : "Μετονομασία",
    "Copy" : "Αντιγραφή",
    "Disconnect storage" : "Αποσυνδεδεμένος αποθηκευτικός χώρος",
    "Unshare" : "Διακοπή διαμοιρασμού",
    "Could not load info for file \"{file}\"" : "Δεν μπορέσαμε να φορτώσουμε πληροφορίες για το αρχείο \"{file}\"",
    "Files" : "Αρχεία",
    "Details" : "Λεπτομέρειες",
    "Select" : "Επιλογή",
    "Pending" : "Εκκρεμεί",
    "Unable to determine date" : "Αδυναμία προσδιορισμού ημερομηνίας ",
    "This operation is forbidden" : "Αυτή η ενέργεια δεν επιτρέπεται",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλώ ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
    "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
    "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Αδυναμία αντιγραφής του \"{file}\". Υπάρχει ήδη.",
    "Could not copy \"{file}\"" : "Αδυναμία αντιγραφής του \"{file}\"",
    "Copied {origin} inside {destination}" : "Αντιγράφτηκε το {origin} στο {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Αντιγράφτηκε το {origin} και {nbfiles} άλλα αρχεία στο {destination}",
    "{newName} already exists" : "Το {newname} υπάρχει ήδη",
    "Could not rename \"{fileName}\", it does not exist any more" : "Δεν μπορέσαμε να μετονομάσουμε \"{fileName}\", το αρχείο δεν υπάρχει πια.",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{targetName}\" χρησιμοποιείται ήδη στον φάκελο\"{dir}\". Παρακαλούμε διαλέξτε ένα διαφορετικό όνομα.",
    "Could not rename \"{fileName}\"" : "Αδυναμία μετονομασίας του \"{fileName}\"",
    "Could not create file \"{file}\"" : "Αδυναμία δημιουργίας του \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Δεν μπορέσαμε να δημιουργήσουμε το αρχείο \"{file}\" επειδή υπάρχει ήδη",
    "Could not create folder \"{dir}\" because it already exists" : "Δεν μπορέσαμε να δημιουργήσουμε τον φάκελο \"{dir}\" επειδή υπάρχει ήδη",
    "Error deleting file \"{fileName}\"." : "Αδυναμία διαγραφής του \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Κανένα αποτέλεσμα αναζήτησης σε άλλους φακέλους για {tag}{filter}{endtag}",
    "Name" : "Όνομα",
    "Size" : "Μέγεθος",
    "Modified" : "Τροποποιήθηκε",
    "_%n folder_::_%n folders_" : ["%n φάκελος","%n φάκελοι"],
    "_%n file_::_%n files_" : ["%n αρχείο","%n αρχεία"],
    "{dirs} and {files}" : "{dirs} και {files}",
    "_including %n hidden_::_including %n hidden_" : ["περιλαμβάνεται %n κρυμμένο ","περιλαμβάνονται %n κρυμμένα "],
    "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα φόρτωσης ή δημιουργίας αρχείων εδώ",
    "_Uploading %n file_::_Uploading %n files_" : ["Ανέβασμα %n αρχείου","Ανέβασμα %n αρχείων"],
    "New" : "Νέο",
    "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
    "File name cannot be empty." : "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" δεν είναι ένας επιτρεπτός τύπος αρχείου",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός χώρος του {owner} είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Ο αποθηκευτικός χώρος του {owner} είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ο αποθηκευτικός χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ταιριάζουν '{filter}' ","ταιριάζουν '{filter}'"],
    "View in folder" : "Προβολή στον φάκελο",
    "Copied!" : "Αντιγράφηκε!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση στο αρχείο/φάκελο)",
    "Path" : "Διαδρομή",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Προτιμώμενα",
    "Favorite" : "Αγαπημένο",
    "New folder" : "Νέος φάκελος",
    "Upload file" : "Αποστολή αρχείου",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα",
    "An error occurred while trying to update the tags" : "Ένα σφάλμα προέκυψε κατά τη διάρκεια ενημέρωσης των ετικετών",
    "Added to favorites" : "Προσθήκη στα αγαπημένα",
    "Removed from favorites" : "Αφαίρεση από τα αγαπημένα",
    "You added {file} to your favorites" : "Προσθέσατε {file} στα αγαπημένα σας",
    "You removed {file} from your favorites" : "Αφαιρέσατε {file} από τα αγαπημένα σας",
    "File changes" : "Αλλαγές αρχείου",
    "Created by {user}" : "Δημιουργήθηκε από τον/την {user}",
    "Changed by {user}" : "Άλλαξε από {user}",
    "Deleted by {user}" : "Διαγράφτηκε από {user}",
    "Restored by {user}" : "Επαναφέρθηκε από {user}",
    "Renamed by {user}" : "Μετονομάστηκε από {user}",
    "Moved by {user}" : "Μετακινήθηκε από {user}",
    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
    "You created {file}" : "Δημιουργήσατε {file}",
    "{user} created {file}" : "{user} δημηούργησε {file}",
    "{file} was created in a public folder" : "{file} δημιουργήθηκε σε δημόσιο φάκελο",
    "You changed {file}" : "Αλλάξατε {file}",
    "{user} changed {file}" : "{user} άλλαξε {file}",
    "You deleted {file}" : "Διαγράψτε το {file}",
    "{user} deleted {file}" : "ο {user} διέγραψε το {file}",
    "You restored {file}" : "Επαναφέρατε {file}",
    "{user} restored {file}" : "{user} επανέφερε {file}",
    "You renamed {oldfile} to {newfile}" : "Μετονομάσατε {oldfile} σε {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} μετονόμασε {oldfile} σε {newfile}",
    "You moved {oldfile} to {newfile}" : "Μεταφέρατε {oldfile} σε {newfile}",
    "{user} moved {oldfile} to {newfile}" : "Μετέφερε {oldfile} σε {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Ένα αρχείο έχει προστεθεί ή αφαιρεθεί από τα <strong>αγαπημένα</strong> σας",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Ένα αρχείο ή φάκελος έχει <strong>αλλάξει</strong> ή <strong>μετονομάστηκε</strong>",
    "A new file or folder has been <strong>created</strong>" : "Ένα νέο αρχείο ή κατάλογος έχουν <strong>δημιουργηθεί</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>διαγραφεί</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Βάλτε όριο στις ειδοποιήσεις για τη δημιουργία και αλλαγές στα <strong>αγαπημένα σας αρχεία</strong> <em>(Μόνο Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "Έγινε <strong>επαναφορά</strong> ενός αρχείου ή φακέλου",
    "Unlimited" : "Απεριόριστο",
    "Upload (max. %s)" : "Διαμοιρασμός (max. %s)",
    "File Management" : "Διαχείριση αρχείων",
    "File handling" : "Διαχείριση αρχείων",
    "Maximum upload size" : "Μέγιστο μέγεθος αποστολής",
    "max. possible: " : "μέγιστο δυνατό:",
    "Save" : "Αποθήκευση",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Με PHP-FPM μπορεί να χρειαστούν μέχρι και 5 λεπτά για να ενεργοποιηθούν οι αλλαγές.",
    "Missing permissions to edit from here." : "Δεν υπάρχουν τα απαραίτητα δικαιώματα για να γίνει τροποποιήση σε αυτό το σημείο.",
    "%s of %s used" : "%s από %s σε χρήση",
    "%s used" : "%sσε χρήση",
    "Settings" : "Ρυθμίσεις",
    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Χρησιμοποιήστε αυτή την διεύθυνση, προκειμένου να <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">έχετε πρόσβαση στα αρχεία σας μέσω WebDAV</a>",
    "Cancel upload" : "Ακύρωση μεταφόρτωσης",
    "No files in here" : "Δεν υπάρχουν αρχεία",
    "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Select all" : "Επιλογή όλων",
    "Upload too large" : "Πολύ μεγάλο αρχείο προς αποστολή",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να ανεβάσετε υπερβαίνουν το μέγιστο μέγεθος αποστολής αρχείων σε αυτόν τον διακομιστή.",
    "No favorites yet" : "Κανένα αγαπημένο ακόμα",
    "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα  θα εμφανιστούν εδώ ",
    "Tags" : "Ετικέτες",
    "Deleted files" : "Διεγραμμένα αρχεία",
    "Shares" : "Κοινόχρηστα",
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "Text file" : "Αρχείο κειμένου",
    "New text file.txt" : "Νέο αρχείο κειμένου.txt",
    "Target folder" : "Φάκελος προορισμού"
},
"nplurals=2; plural=(n != 1);");
